summaryrefslogtreecommitdiffstats
path: root/include/oox/dump
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2015-02-19 08:40:27 +0000
committerCaolán McNamara <caolanm@redhat.com>2015-02-19 09:55:18 +0000
commit8f2522f931df9f1f24ef7016ee64d75fd23af000 (patch)
tree59ad157d1683dc311e8688c5b4193754f0e178b8 /include/oox/dump
parenttdf#83099 fix Top of formula bar is missing when expanding on Windows 7 (diff)
downloadcore-8f2522f931df9f1f24ef7016ee64d75fd23af000.tar.gz
core-8f2522f931df9f1f24ef7016ee64d75fd23af000.zip
boost->std
Change-Id: Icae6b6f07ad8dbd287fdfc689739187883a07775
Diffstat (limited to 'include/oox/dump')
-rw-r--r--include/oox/dump/dumperbase.hxx30
-rw-r--r--include/oox/dump/xlsbdumper.hxx2
2 files changed, 16 insertions, 16 deletions
diff --git a/include/oox/dump/xlsbdumper.hxx b/include/oox/dump/xlsbdumper.hxx
index f597fa15ef4b..3a9e7b0b082a 100644
--- a/include/oox/dump/xlsbdumper.hxx
+++ b/include/oox/dump/xlsbdumper.hxx
@@ -87,7 +87,7 @@ private:
bool readCompressedInt( BinaryInputStream& rStrm, sal_Int32& ornValue );
private:
- typedef ::boost::shared_ptr< SequenceInputStream > SequenceInputStreamRef;
+ typedef std::shared_ptr< SequenceInputStream > SequenceInputStreamRef;
SequenceInputStreamRef mxBiffStrm;
NameListRef mxErrCodes;
diff --git a/include/oox/dump/dumperbase.hxx b/include/oox/dump/dumperbase.hxx
index 5bdb01f05d02..b1e486ea2203 100644
--- a/include/oox/dump/dumperbase.hxx
+++ b/include/oox/dump/dumperbase.hxx
@@ -25,7 +25,7 @@
#include <stack>
#include <set>
#include <map>
-#include <boost/shared_ptr.hpp>
+#include <memory>
#include <rtl/strbuf.hxx>
#include <rtl/ustrbuf.hxx>
#include <com/sun/star/uno/Reference.hxx>
@@ -151,7 +151,7 @@ public:
::oox::BinaryInputStreamRef( new BinaryXInputStream( rxInStrm, true ) ) {}
template< typename StreamType >
/*implicit*/ BinaryInputStreamRef( const ::boost::shared_ptr< StreamType >& rxInStrm ) :
::oox::BinaryInputStreamRef( rxInStrm ) {}
};
@@ -447,7 +447,7 @@ static const String EMPTY_STRING;
class Base;
-typedef ::boost::shared_ptr< Base > BaseRef;
+typedef std::shared_ptr< Base > BaseRef;
/** Base class for all dumper classes.
@@ -557,7 +557,7 @@ class SharedConfigData;
class Config;
class NameListBase;
-typedef ::boost::shared_ptr< NameListBase > NameListRef;
+typedef std::shared_ptr< NameListBase > NameListRef;
/** Base class of all classes providing names for specific values (name lists).
@@ -848,7 +848,7 @@ public:
const OUString* getOption( const OUString& rKey ) const;
template< typename ListType >
- ::boost::shared_ptr< ListType > createNameList( const OUString& rListName );
+ std::shared_ptr< ListType > createNameList( const OUString& rListName );
void setNameList( const OUString& rListName, const NameListRef& rxList );
void eraseNameList( const OUString& rListName );
NameListRef getNameList( const OUString& rListName ) const;
@@ -888,9 +888,9 @@ private:
template< typename ListType >
-::boost::shared_ptr< ListType > SharedConfigData::createNameList( const OUString& rListName )
+std::shared_ptr< ListType > SharedConfigData::createNameList( const OUString& rListName )
{
- ::boost::shared_ptr< ListType > xList;
+ std::shared_ptr< ListType > xList;
if( !rListName.isEmpty() )
{
xList.reset( new ListType( *this ) );
@@ -937,7 +937,7 @@ public:
bool isImportEnabled() const;
template< typename ListType >
- ::boost::shared_ptr< ListType > createNameList( const String& rListName );
+ std::shared_ptr< ListType > createNameList( const String& rListName );
void eraseNameList( const String& rListName );
NameListRef getNameList( const String& rListName ) const;
@@ -967,11 +967,11 @@ protected:
NameListRef implGetNameList( const OUString& rListName ) const;
private:
- typedef ::boost::shared_ptr< SharedConfigData > SharedConfigDataRef;
+ typedef std::shared_ptr< SharedConfigData > SharedConfigDataRef;
SharedConfigDataRef mxCfgData;
};
-typedef ::boost::shared_ptr< Config > ConfigRef;
+typedef std::shared_ptr< Config > ConfigRef;
@@ -985,7 +985,7 @@ Type Config::getIntOption( const String& rKey, Type nDefault ) const
}
template< typename ListType >
-::boost::shared_ptr< ListType > Config::createNameList( const String& rListName )
+std::shared_ptr< ListType > Config::createNameList( const String& rListName )
{
return mxCfgData->createNameList< ListType >( rListName );
}
@@ -1093,7 +1093,7 @@ private:
sal_Int32 mnLastItem;
};
-typedef ::boost::shared_ptr< Output > OutputRef;
+typedef std::shared_ptr< Output > OutputRef;
@@ -1217,7 +1217,7 @@ private:
ConfigRef mxConfig;
};
-typedef ::boost::shared_ptr< ObjectBase > ObjectRef;
+typedef std::shared_ptr< ObjectBase > ObjectRef;
@@ -1710,7 +1710,7 @@ private:
void constructTextStrmObj( rtl_TextEncoding eTextEnc );
protected:
- ::boost::shared_ptr< TextInputStream > mxTextStrm;
+ std::shared_ptr< TextInputStream > mxTextStrm;
};
@@ -1820,7 +1820,7 @@ protected:
virtual bool implReadRecordHeader( BinaryInputStream& rBaseStrm, sal_Int64& ornRecId, sal_Int64& ornRecSize ) = 0;
private:
- typedef ::boost::shared_ptr< StreamDataSequence > StreamDataSeqRef;
+ typedef std::shared_ptr< StreamDataSequence > StreamDataSeqRef;
StreamDataSeqRef mxRecData;
};
@@ -151,7 +151,7 @@ public:
::oox::BinaryInputStreamRef( new BinaryXInputStream( rxInStrm, true ) ) {}
template< typename StreamType >
- /*implicit*/ BinaryInputStreamRef( const ::boost::shared_ptr< StreamType >& rxInStrm ) :
+ /*implicit*/ BinaryInputStreamRef( const std::shared_ptr< StreamType >& rxInStrm ) :
::oox::BinaryInputStreamRef( rxInStrm ) {}
};